@@ -891,7 +891,8 @@ def Transpose(src, dst):
 
 def GridDistortion(src, dst, num_steps=5, distort_limit=None,
                    interp=InterpolationType.linear,
-                   border_type=BorderType.BORDER_REFLECT_101, border_value=0):
+                   border_type=BorderType.BORDER_REFLECT_101, border_value=0,
+                   seed=None):
     """\
     Divide the image into a cell grid and randomly stretch or reduce each cell.
 
@@ -903,18 +904,22 @@ def GridDistortion(src, dst, num_steps=5, distort_limit=None,
     :param border_type: pixel extrapolation method, see BorderType
     :param border_value: padding value if border_type is
       BorderType.BORDER_CONSTANT
+    :param seed: seed for the random number generator
     :return: None
     """
     if distort_limit is None:
         distort_limit = [-0.3, 0.3]
+    if seed is None:
+        return _ecvl.GridDistortion(src, dst, num_steps, distort_limit,
+                                    interp, border_type, border_value)
     return _ecvl.GridDistortion(src, dst, num_steps, distort_limit,
-                                interp, border_type, border_value)
+                                interp, border_type, border_value, seed)
 
 
 def ElasticTransform(src, dst, alpha=34, sigma=4,
                      interp=InterpolationType.linear,
                      border_type=BorderType.BORDER_REFLECT_101,
-                     border_value=0):
+                     border_value=0, seed=None):
     """\
     Elastic deformation of input image.
 
@@ -927,10 +932,93 @@ def ElasticTransform(src, dst, alpha=34, sigma=4,
     :param border_type: pixel extrapolation method, see BorderType
     :param border_value: padding value if border_type is
       BorderType.BORDER_CONSTANT
+    :param seed: seed for the random number generator
     :return: None
     """
+    if seed is None:
+        return _ecvl.ElasticTransform(src, dst, alpha, sigma, interp,
+                                      border_type, border_value)
     return _ecvl.ElasticTransform(src, dst, alpha, sigma, interp, border_type,
-                                  border_value)
+                                  border_value, seed)
+
+
+def OpticalDistortion(src, dst, distort_limit=None, shift_limit=None,
+                      interp=InterpolationType.linear,
+                      border_type=BorderType.BORDER_REFLECT_101,
+                      border_value=0, seed=None):
+    """\
+    Barrel / pincushion distortion.
+
+    :param src: input image
+    :param dst: output image
+    :param distort_limit: distortion intensity range
+    :param shift_limit: image shifting range
+    :param interp: InterpolationType to be used
+    :param border_type: pixel extrapolation method, see BorderType
+    :param border_value: padding value if border_type is
+      BorderType.BORDER_CONSTANT
+    :param seed: seed for the random number generator
+    :return: None
+    """
+    if distort_limit is None:
+        distort_limit = [-0.3, 0.3]
+    if shift_limit is None:
+        shift_limit = [-0.1, 0.1]
+    if seed is None:
+        return _ecvl.OpticalDistortion(src, dst, distort_limit, shift_limit,
+                                       interp, border_type, border_value)
+    return _ecvl.OpticalDistortion(src, dst, distort_limit, shift_limit,
+                                   interp, border_type, border_value, seed)
+
+
+def Salt(src, dst, p, per_channel=False, seed=None):
+    """\
+    Add salt noise (white pixels) to the input image.
+
+    :param src: input image
+    :param dst: output image
+    :param p: probability of replacing a pixel with salt noise
+    :param per_channel: if True, apply channel-wide noise
+    :param seed: seed for the random number generator
+    :return: None
+    """
+    if seed is None:
+        return _ecvl.Salt(src, dst, p, per_channel)
+    return _ecvl.Salt(src, dst, p, per_channel, seed)
+
+
+def Pepper(src, dst, p, per_channel=False, seed=None):
+    """\
+    Add pepper noise (black pixels) to the input image.
+
+    :param src: input image
+    :param dst: output image
+    :param p: probability of replacing a pixel with pepper noise
+    :param per_channel: if True, apply channel-wide noise
+    :param seed: seed for the random number generator
+    :return: None
+    """
+    if seed is None:
+        return _ecvl.Pepper(src, dst, p, per_channel)
+    return _ecvl.Pepper(src, dst, p, per_channel, seed)
+
+
+def SaltAndPepper(src, dst, p, per_channel=False, seed=None):
+    """\
+    Add salt and pepper noise (white and black pixels) to the input image.
+
+    White and black pixels are equally likely.
+
+    :param src: input image
+    :param dst: output image
+    :param p: probability of replacing a pixel with salt or pepper noise
+    :param per_channel: if True, apply channel-wide noise
+    :param seed: seed for the random number generator
+    :return: None
+    """
+    if seed is None:
+        return _ecvl.SaltAndPepper(src, dst, p, per_channel)
+    return _ecvl.SaltAndPepper(src, dst, p, per_channel, seed)
 
 
 # == dataset_parser ==
@@ -1091,6 +1179,37 @@ class SequentialAugmentationContainer(_ecvl.SequentialAugmentationContainer):
         _ecvl.SequentialAugmentationContainer.__init__(self, augs)
 
 
+class OneOfAugmentationContainer(_ecvl.OneOfAugmentationContainer):
+    """\
+    A container for multiple augmentations, from which one is randomly chosen.
+
+    The chosen augmentation will be applied with a user-specified probability.
+    """
+
+    @staticmethod
+    def fromtext(txt):
+        r"""\
+        Create a OneOfAugmentationContainer from a text description,
+        e.g.::
+
+            txt = '''\
+            p=0.7
+            AugFlip p=0.2
+            AugMirror p=0.4
+            end
+            '''
+            c = OneOfAugmentationContainer(txt)
+        """
+        return _ecvl.OneOfAugmentationContainer(txt)
+
+    def __init__(self, p, augs):
+        """\
+        :param p: probability of applying the chosen augmentation
+        :param augs: list of augmentations
+        """
+        _ecvl.OneOfAugmentationContainer.__init__(self, p, augs)
+
+
 class AugRotate(_ecvl.AugRotate):
     """\
     Augmentation wrapper for Rotate2D.
@@ -1435,6 +1554,110 @@ class AugElasticTransform(_ecvl.AugElasticTransform):
                                            border_type, border_value)
 
 
+class AugOpticalDistortion(_ecvl.AugOpticalDistortion):
+    """\
+    Augmentation wrapper for OpticalDistortion.
+    """
+
+    @staticmethod
+    def fromtext(txt):
+        r"""\
+        Create an AugOpticalDistortion from a text description, e.g.::
+
+            a = AugOpticalDistortion('distort_limit=[-0.2,0.2] '
+                                     'shift_limit=[-0.4,0.4] '
+                                     'interp=\"linear\" '
+                                     'border_type=\"reflect_101\" '
+                                     'border_value=0')
+        """
+        return _ecvl.AugOpticalDistortion(txt)
+
+    def __init__(self, distort_limit, shift_limit,
+                 interp=InterpolationType.linear,
+                 border_type=BorderType.BORDER_REFLECT_101, border_value=0):
+        """\
+        :param distort_limit: range of values ``[min, max]`` to randomly select
+          the distortion steps
+        :param shift_limit: range of values ``[min, max]`` to randomly select
+          the image shifting
+        :param interp: InterpolationType to be used
+        :param border_type: pixel extrapolation method, see BorderType
+        :param border_value: padding value if border_type is
+          BorderType.BORDER_CONSTANT
+        """
+        _ecvl.AugOpticalDistortion.__init__(self, distort_limit, shift_limit,
+                                            interp, border_type, border_value)
+
+
+class AugSalt(_ecvl.AugSalt):
+    """\
+    Augmentation wrapper for Salt.
+    """
+
+    @staticmethod
+    def fromtext(txt):
+        r"""\
+        Create an AugSalt from a text description, e.g.::
+
+            a = AugSalt('p=[0.1,0.3] per_channel=0.5')
+        """
+        return _ecvl.AugSalt(txt)
+
+    def __init__(self, p, per_channel):
+        """\
+        :param p: range of values ``[min, max]`` for the probability of any
+          pixel to be set to white
+        :param per_channel: probability to use the same value for all channels
+        """
+        _ecvl.AugSalt.__init__(self, p, per_channel)
+
+
+class AugPepper(_ecvl.AugPepper):
+    """\
+    Augmentation wrapper for Pepper.
+    """
+
+    @staticmethod
+    def fromtext(txt):
+        r"""\
+        Create an AugPepper from a text description, e.g.::
+
+            a = AugPepper('p=[0.1,0.3] per_channel=0.5')
+        """
+        return _ecvl.AugPepper(txt)
+
+    def __init__(self, p, per_channel):
+        """\
+        :param p: range of values ``[min, max]`` for the probability of any
+          pixel to be set to black
+        :param per_channel: probability to use the same value for all channels
+        """
+        _ecvl.AugPepper.__init__(self, p, per_channel)
+
+
+class AugSaltAndPepper(_ecvl.AugSaltAndPepper):
+    """\
+    Augmentation wrapper for SaltAndPepper.
+    """
+
+    @staticmethod
+    def fromtext(txt):
+        r"""\
+        Create an AugSaltAndPepper from a text description, e.g.::
+
+            a = AugSaltAndPepper('p=[0.1,0.3] per_channel=0.5')
+        """
+        return _ecvl.AugSaltAndPepper(txt)
+
+    def __init__(self, p, per_channel):
+        """\
+        :param p: range of values ``[min, max]`` for the probability of any
+          pixel to be set to white or black
+        :param per_channel: probability to use the same value for all channels
+        """
+        _ecvl.AugSaltAndPepper.__init__(self, p, per_channel)
+
+
 # == support_imgcodecs ==
 
 class ImReadMode(_ecvl.ImReadMode):
